/*
 * Copyright 1999-2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/***************************************************************************
 * Description: DSAPI plugin for Lotus Domino                              *
 * Author:      Andy Armstrong <andy@tagish.com>                           *
 * Version:     $Revision: 1.9 $                                           *
 ***************************************************************************/

#ifndef __config_h
#define __config_h

#include "jk_version.h"

#ifndef MAKEVERSION
#  define MAKEVERSION(a, b, c, d) \
	(((a) << 24) + ((b) << 16) + ((c) << 8) + (d))
#endif

/* the _memicmp() function is available */
#if defined(WIN32)

#  define HAVE_MEMICMP
#  define HAVE_STRICMP
#  undef USE_INIFILE

#elif defined(LINUX) || defined (SOLARIS)

#  undef HAVE_MEMICMP
#  undef HAVE_STRICMP
#  define USE_INIFILE

#else
#  error "Please define one of WIN32, LINUX or SOLARIS"
#endif

/*
 * define if you don't have the Notes C API which is available from
 *
 *    http://www-128.ibm.com/developerworks/lotus/downloads/toolkits.html
 *    http://www-12.lotus.com/ldd/doc/tools/c/6.5/api65ug.nsf
 *    http://doc.notes.net/tools/c/6.5/api65ref.nsf
 */
#if defined(NO_CAPI)
#  error "Please download Notes C API from http://www-128.ibm.com/developerworks/lotus/downloads/toolkits.html and install it"
#endif

#if defined(DEBUG)
#  undef DEBUG
#  define DEBUG(args) \
	do { printf args ; } while (0)
#else
#  define DEBUG(args)
#endif

#if defined( DEBUGLOG )
#  if defined( WIN32 )
#    define DEBUGLOGFILE "c:\\notes\\notesdata\\dsapi.log"
#  else
#    define DEBUGLOGFILE "/var/log/lotus/dsapi.log"
#  endif
#endif

/* New versions of Tomcat connectors API change the names of some methods */
#if defined(JK_VERSION) && JK_VERSION >= MAKEVERSION(1, 2, 19, 0)
#  define map_read_properties(a,b) jk_map_read_properties(a,b,NULL,logger)
#  define map_alloc(a) jk_map_alloc(a)
#  define map_free(a) jk_map_free(a)
#endif

#endif /* __config_h */
